# MolClustPy

## Python package to characterize the multivalent biomolecular clusters 

<b>MolClustPy</b> is a Python package to perform multiple stochastic simulation runs using NFsim (Network-Free stochastic simulator, [Sneddon et al, 2011](https://pubmed.ncbi.nlm.nih.gov/21186362/)) and characterize distribution of cluster sizes, molecular composition, and bonds across molecular clusters and individual molecules of different types. 


Github:
https://github.com/achattaraj/MolClustPy

Website:
https://molclustpy.github.io/